Class: Line::Bot::Event::Leave Deprecated
- Defined in:
- lib/line/bot/v1/event/leave.rb
Overview
Deprecated.
This is deprecated. Please use V2::Webhook::LeaveEvent instead.
Event object for when a user removes your LINE official account from a group or when your LINE official account leaves a group or room.
No replyToken is generated for this event.
Method Summary
Methods inherited from Base
Constructor Details
This class inherits a constructor from Line::Bot::Event::Base