Class: Line::Bot::V2::Insight::ErrorDetail
- Inherits:
-
Object
- Object
- Line::Bot::V2::Insight::ErrorDetail
- Defined in:
- lib/line/bot/v2/insight/model/error_detail.rb
Overview
Instance Attribute Summary collapse
-
#message ⇒ String?
Details of the error.
-
#property ⇒ String?
Location of where the error occurred.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Insight::ErrorDetail
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(message: nil, property: nil, **dynamic_attributes) ⇒ ErrorDetail
constructor
A new instance of ErrorDetail.
Constructor Details
#initialize(message: nil, property: nil, **dynamic_attributes) ⇒ ErrorDetail
Returns a new instance of ErrorDetail.
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/line/bot/v2/insight/model/error_detail.rb', line 25 def initialize( message: nil, property: nil, **dynamic_attributes ) @message = @property = property dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#message ⇒ String?
Returns Details of the error. Not included in the response under certain situations.
18 19 20 |
# File 'lib/line/bot/v2/insight/model/error_detail.rb', line 18 def @message end |
#property ⇒ String?
Returns Location of where the error occurred. Returns the JSON field name or query parameter name of the request. Not included in the response under certain situations.
21 22 23 |
# File 'lib/line/bot/v2/insight/model/error_detail.rb', line 21 def property @property end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Insight::ErrorDetail
Create an instance of the class from a hash
50 51 52 53 |
# File 'lib/line/bot/v2/insight/model/error_detail.rb', line 50 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
57 58 59 60 61 62 63 |
# File 'lib/line/bot/v2/insight/model/error_detail.rb', line 57 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
66 67 68 |
# File 'lib/line/bot/v2/insight/model/error_detail.rb', line 66 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |