Class: Line::Bot::V2::Insight::GetMessageEventResponseClick
- Inherits:
-
Object
- Object
- Line::Bot::V2::Insight::GetMessageEventResponseClick
- Defined in:
- lib/line/bot/v2/insight/model/get_message_event_response_click.rb
Overview
Instance Attribute Summary collapse
-
#click ⇒ Integer?
Number of times the URL was opened.
-
#seq ⇒ Integer?
The URL’s serial number.
-
#unique_click ⇒ Integer?
Number of users that opened the URL.
-
#unique_click_of_request ⇒ Integer?
Number of users who opened this url through any link in the message.
-
#url ⇒ String?
URL.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Insight::GetMessageEventResponseClick
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(seq: nil, url: nil, click: nil, unique_click: nil, unique_click_of_request: nil, **dynamic_attributes) ⇒ GetMessageEventResponseClick
constructor
A new instance of GetMessageEventResponseClick.
Constructor Details
#initialize(seq: nil, url: nil, click: nil, unique_click: nil, unique_click_of_request: nil, **dynamic_attributes) ⇒ GetMessageEventResponseClick
Returns a new instance of GetMessageEventResponseClick.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/line/bot/v2/insight/model/get_message_event_response_click.rb', line 37 def initialize( seq: nil, url: nil, click: nil, unique_click: nil, unique_click_of_request: nil, **dynamic_attributes ) @seq = seq @url = url @click = click @unique_click = unique_click @unique_click_of_request = unique_click_of_request dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#click ⇒ Integer?
Returns Number of times the URL was opened.
24 25 26 |
# File 'lib/line/bot/v2/insight/model/get_message_event_response_click.rb', line 24 def click @click end |
#seq ⇒ Integer?
Returns The URL’s serial number.
18 19 20 |
# File 'lib/line/bot/v2/insight/model/get_message_event_response_click.rb', line 18 def seq @seq end |
#unique_click ⇒ Integer?
Returns Number of users that opened the URL.
27 28 29 |
# File 'lib/line/bot/v2/insight/model/get_message_event_response_click.rb', line 27 def unique_click @unique_click end |
#unique_click_of_request ⇒ Integer?
Returns Number of users who opened this url through any link in the message. If a message contains two links to the same URL and a user opens both links, they’re counted only once.
30 31 32 |
# File 'lib/line/bot/v2/insight/model/get_message_event_response_click.rb', line 30 def unique_click_of_request @unique_click_of_request end |
#url ⇒ String?
Returns URL.
21 22 23 |
# File 'lib/line/bot/v2/insight/model/get_message_event_response_click.rb', line 21 def url @url end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Insight::GetMessageEventResponseClick
Create an instance of the class from a hash
68 69 70 71 |
# File 'lib/line/bot/v2/insight/model/get_message_event_response_click.rb', line 68 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
75 76 77 78 79 80 81 |
# File 'lib/line/bot/v2/insight/model/get_message_event_response_click.rb', line 75 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
84 85 86 |
# File 'lib/line/bot/v2/insight/model/get_message_event_response_click.rb', line 84 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |