Class: Line::Bot::V2::Insight::GetMessageEventResponseOverview

Inherits:
Object
  • Object
show all
Defined in:
lib/line/bot/v2/insight/model/get_message_event_response_overview.rb

Overview

Summary of message statistics.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(request_id: nil, timestamp: nil, delivered: nil, unique_impression: nil, unique_click: nil, unique_media_played: nil, unique_media_played100_percent: nil, **dynamic_attributes) ⇒ GetMessageEventResponseOverview

Returns a new instance of GetMessageEventResponseOverview.

Parameters:

  • request_id (String, nil) (defaults to: nil)

    Request ID.

  • timestamp (Integer, nil) (defaults to: nil)

    UNIX timestamp for message delivery time in seconds.

  • delivered (Integer, nil) (defaults to: nil)

    Number of messages delivered. This property shows values of less than 20. However, if all messages have not been sent, it will be null.

  • unique_impression (Integer, nil) (defaults to: nil)

    Number of users who opened the message, meaning they displayed at least 1 bubble.

  • unique_click (Integer, nil) (defaults to: nil)

    Number of users who opened any URL in the message.

  • unique_media_played (Integer, nil) (defaults to: nil)

    Number of users who started playing any video or audio in the message.

  • unique_media_played100_percent (Integer, nil) (defaults to: nil)

    Number of users who played the entirety of any video or audio in the message.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 46

def initialize(
  request_id: nil,
  timestamp: nil,
  delivered: nil,
  unique_impression: nil,
  unique_click: nil,
  unique_media_played: nil,
  unique_media_played100_percent: nil,
  **dynamic_attributes
)
  
  @request_id = request_id
  @timestamp = timestamp
  @delivered = delivered
  @unique_impression = unique_impression
  @unique_click = unique_click
  @unique_media_played = unique_media_played
  @unique_media_played100_percent = unique_media_played100_percent

  dynamic_attributes.each do |key, value|
    self.class.attr_accessor key

    if value.is_a?(Hash)
      struct_klass = Struct.new(*value.keys.map(&:to_sym))
      struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v }
      instance_variable_set("@#{key}", struct_klass.new(*struct_values))
    else
      instance_variable_set("@#{key}", value)
    end
  end
end

Instance Attribute Details

#deliveredInteger?

Returns Number of messages delivered. This property shows values of less than 20. However, if all messages have not been sent, it will be null.

Returns:

  • (Integer, nil)

    Number of messages delivered. This property shows values of less than 20. However, if all messages have not been sent, it will be null.



25
26
27
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 25

def delivered
  @delivered
end

#request_idString?

Returns Request ID.

Returns:

  • (String, nil)

    Request ID.



19
20
21
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 19

def request_id
  @request_id
end

#timestampInteger?

Returns UNIX timestamp for message delivery time in seconds.

Returns:

  • (Integer, nil)

    UNIX timestamp for message delivery time in seconds.



22
23
24
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 22

def timestamp
  @timestamp
end

#unique_clickInteger?

Returns Number of users who opened any URL in the message.

Returns:

  • (Integer, nil)

    Number of users who opened any URL in the message.



31
32
33
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 31

def unique_click
  @unique_click
end

#unique_impressionInteger?

Returns Number of users who opened the message, meaning they displayed at least 1 bubble.

Returns:

  • (Integer, nil)

    Number of users who opened the message, meaning they displayed at least 1 bubble.



28
29
30
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 28

def unique_impression
  @unique_impression
end

#unique_media_playedInteger?

Returns Number of users who started playing any video or audio in the message.

Returns:

  • (Integer, nil)

    Number of users who started playing any video or audio in the message.



34
35
36
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 34

def unique_media_played
  @unique_media_played
end

#unique_media_played100_percentInteger?

Returns Number of users who played the entirety of any video or audio in the message.

Returns:

  • (Integer, nil)

    Number of users who played the entirety of any video or audio in the message.



37
38
39
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 37

def unique_media_played100_percent
  @unique_media_played100_percent
end

Class Method Details

.create(args) ⇒ Line::Bot::V2::Insight::GetMessageEventResponseOverview

Create an instance of the class from a hash

Parameters:

  • args (Hash)

    Hash containing all the required attributes

Returns:



81
82
83
84
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 81

def self.create(args)
  symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args)
  return new(**symbolized_args)
end

Instance Method Details

#==(other) ⇒ Boolean

Returns true if the objects are equal, false otherwise.

Parameters:

  • other (Object)

    Object to compare

Returns:

  • (Boolean)

    true if the objects are equal, false otherwise



88
89
90
91
92
93
94
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 88

def ==(other)
  return false unless self.class == other.class

  instance_variables.all? do |var|
      instance_variable_get(var) == other.instance_variable_get(var)
  end
end

#hashInteger

Returns Hash code of the object.

Returns:

  • (Integer)

    Hash code of the object



97
98
99
# File 'lib/line/bot/v2/insight/model/get_message_event_response_overview.rb', line 97

def hash
  [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash
end