Class: Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseBounds
- Inherits:
-
Object
- Object
- Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseBounds
- Defined in:
- lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rb,
sig/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rbs
Overview
Target area of the metrics, represented by the top-left coordinate, width, and height.
Instance Attribute Summary collapse
-
#height ⇒ Integer
The height of the target area.
-
#width ⇒ Integer
The width of the target area.
-
#x ⇒ Integer
The x coordinate of the top-left corner of the target area.
-
#y ⇒ Integer
The y coordinate of the top-left corner of the target area.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseBounds
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
- #initialize(x:, y:, width:, height:, **dynamic_attributes) ⇒ Object constructor
Constructor Details
#initialize(x:, y:, width:, height:, **dynamic_attributes) ⇒ Object
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rb', line 33 def initialize( x:, y:, width:, height:, **dynamic_attributes ) @x = x @y = y @width = width @height = height dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#height ⇒ Integer
Returns The height of the target area.
27 28 29 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rb', line 27 def height @height end |
#width ⇒ Integer
Returns The width of the target area.
24 25 26 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rb', line 24 def width @width end |
#x ⇒ Integer
Returns The x coordinate of the top-left corner of the target area.
18 19 20 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rb', line 18 def x @x end |
#y ⇒ Integer
Returns The y coordinate of the top-left corner of the target area.
21 22 23 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rb', line 21 def y @y end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseBounds
Create an instance of the class from a hash
62 63 64 65 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rb', line 62 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
69 70 71 72 73 74 75 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rb', line 69 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
78 79 80 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_bounds.rb', line 78 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |