Class: Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseClick
- Inherits:
-
Object
- Object
- Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseClick
- Defined in:
- lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_click.rb,
sig/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_click.rbs
Overview
Daily click metrics for a single tappable area of the rich menu.
Instance Attribute Summary collapse
- #bounds ⇒ GetRichMenuInsightDailyResponseBounds
-
#metrics ⇒ Array[GetRichMenuInsightDailyResponseDailyMetrics]
Per-day click metrics for the target area.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseClick
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
- #initialize(bounds:, metrics:, **dynamic_attributes) ⇒ Object constructor
Constructor Details
#initialize(bounds:, metrics:, **dynamic_attributes) ⇒ Object
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_click.rb', line 25 def initialize( bounds:, metrics:, **dynamic_attributes ) @bounds = bounds.is_a?(Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseBounds) ? bounds : Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseBounds.create(**bounds) @metrics = metrics.map do |item| if item.is_a?(Hash) Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseDailyMetrics.create(**item) else item end end dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#bounds ⇒ GetRichMenuInsightDailyResponseBounds
18 19 20 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_click.rb', line 18 def bounds @bounds end |
#metrics ⇒ Array[GetRichMenuInsightDailyResponseDailyMetrics]
Returns Per-day click metrics for the target area.
21 22 23 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_click.rb', line 21 def metrics @metrics end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Insight::GetRichMenuInsightDailyResponseClick
Create an instance of the class from a hash
56 57 58 59 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_click.rb', line 56 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
63 64 65 66 67 68 69 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_click.rb', line 63 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
72 73 74 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_daily_response_click.rb', line 72 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |