Class: Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseBounds

Inherits:
Object
  • Object
show all
Defined in:
lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rb,
sig/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rbs

Overview

Target area of the metrics, represented by the top-left coordinate, width, and height.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(x:, y:, width:, height:, **dynamic_attributes) ⇒ Object

Parameters:

  • x (Integer)

    The x coordinate of the top-left corner of the target area.

  • y (Integer)

    The y coordinate of the top-left corner of the target area.

  • width (Integer)

    The width of the target area.

  • height (Integer)

    The height of the target area.



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rb', line 33

def initialize(
  x:,
  y:,
  width:,
  height:,
  **dynamic_attributes
)
  
  @x = x
  @y = y
  @width = width
  @height = height

  dynamic_attributes.each do |key, value|
    self.class.attr_accessor key

    if value.is_a?(Hash)
      struct_klass = Struct.new(*value.keys.map(&:to_sym))
      struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v }
      instance_variable_set("@#{key}", struct_klass.new(*struct_values))
    else
      instance_variable_set("@#{key}", value)
    end
  end
end

Instance Attribute Details

#heightInteger

Returns The height of the target area.

Returns:

  • (Integer)

    The height of the target area.



27
28
29
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rb', line 27

def height
  @height
end

#widthInteger

Returns The width of the target area.

Returns:

  • (Integer)

    The width of the target area.



24
25
26
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rb', line 24

def width
  @width
end

#xInteger

Returns The x coordinate of the top-left corner of the target area.

Returns:

  • (Integer)

    The x coordinate of the top-left corner of the target area.



18
19
20
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rb', line 18

def x
  @x
end

#yInteger

Returns The y coordinate of the top-left corner of the target area.

Returns:

  • (Integer)

    The y coordinate of the top-left corner of the target area.



21
22
23
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rb', line 21

def y
  @y
end

Class Method Details

.create(args) ⇒ Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseBounds

Create an instance of the class from a hash

Parameters:

  • args (Hash)

    Hash containing all the required attributes

  • (Hash[Symbol, untyped])

Returns:



62
63
64
65
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rb', line 62

def self.create(args)
  symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args)
  return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments
end

Instance Method Details

#==(other) ⇒ Boolean

Returns true if the objects are equal, false otherwise.

Parameters:

  • other (Object)

    Object to compare

Returns:

  • (Boolean)

    true if the objects are equal, false otherwise



69
70
71
72
73
74
75
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rb', line 69

def ==(other)
  return false unless self.class == other.class

  instance_variables.all? do |var|
      instance_variable_get(var) == other.instance_variable_get(var)
  end
end

#hashInteger

Returns Hash code of the object.

Returns:

  • (Integer)

    Hash code of the object



78
79
80
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_bounds.rb', line 78

def hash
  [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash
end