Class: Line::Bot::V2::Liff::LiffFeatures
- Inherits:
-
Object
- Object
- Line::Bot::V2::Liff::LiffFeatures
- Defined in:
- lib/line/bot/v2/liff/model/liff_features.rb
Overview
Instance Attribute Summary collapse
-
#ble ⇒ Boolean?
‘true` if the LIFF app supports Bluetooth® Low Energy for LINE Things.
-
#qr_code ⇒ Boolean?
‘true` to use the 2D code reader in the LIFF app.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Liff::LiffFeatures
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(ble: nil, qr_code: false, **dynamic_attributes) ⇒ LiffFeatures
constructor
A new instance of LiffFeatures.
Constructor Details
#initialize(ble: nil, qr_code: false, **dynamic_attributes) ⇒ LiffFeatures
Returns a new instance of LiffFeatures.
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/line/bot/v2/liff/model/liff_features.rb', line 25 def initialize( ble: nil, qr_code: false, **dynamic_attributes ) @ble = ble @qr_code = qr_code dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#ble ⇒ Boolean?
Returns ‘true` if the LIFF app supports Bluetooth® Low Energy for LINE Things. `false` otherwise.
18 19 20 |
# File 'lib/line/bot/v2/liff/model/liff_features.rb', line 18 def ble @ble end |
#qr_code ⇒ Boolean?
Returns ‘true` to use the 2D code reader in the LIFF app. false otherwise. The default value is `false`.
21 22 23 |
# File 'lib/line/bot/v2/liff/model/liff_features.rb', line 21 def qr_code @qr_code end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Liff::LiffFeatures
Create an instance of the class from a hash
50 51 52 53 |
# File 'lib/line/bot/v2/liff/model/liff_features.rb', line 50 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
57 58 59 60 61 62 63 |
# File 'lib/line/bot/v2/liff/model/liff_features.rb', line 57 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
66 67 68 |
# File 'lib/line/bot/v2/liff/model/liff_features.rb', line 66 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |