Class: Line::Bot::V2::Liff::UpdateLiffAppRequest
- Inherits:
-
Object
- Object
- Line::Bot::V2::Liff::UpdateLiffAppRequest
- Defined in:
- lib/line/bot/v2/liff/model/update_liff_app_request.rb
Overview
Instance Attribute Summary collapse
-
#bot_prompt ⇒ String?
(‘normal’|‘aggressive’|‘none’).
-
#description ⇒ String?
Name of the LIFF app.
- #features ⇒ LiffFeatures?
-
#permanent_link_pattern ⇒ String?
How additional information in LIFF URLs is handled.
- #scope ⇒ Array['openid','email','profile','chat_message.write']
- #view ⇒ UpdateLiffView?
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Liff::UpdateLiffAppRequest
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(view: nil, description: nil, features: nil, permanent_link_pattern: nil, scope: nil, bot_prompt: nil, **dynamic_attributes) ⇒ UpdateLiffAppRequest
constructor
A new instance of UpdateLiffAppRequest.
Constructor Details
#initialize(view: nil, description: nil, features: nil, permanent_link_pattern: nil, scope: nil, bot_prompt: nil, **dynamic_attributes) ⇒ UpdateLiffAppRequest
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 41 def initialize( view: nil, description: nil, features: nil, permanent_link_pattern: nil, scope: nil, bot_prompt: nil, **dynamic_attributes ) @view = view.is_a?(Line::Bot::V2::Liff::UpdateLiffView) || view.nil? ? view : Line::Bot::V2::Liff::UpdateLiffView.create(**view) # steep:ignore @description = description @features = features.is_a?(Line::Bot::V2::Liff::LiffFeatures) || features.nil? ? features : Line::Bot::V2::Liff::LiffFeatures.create(**features) # steep:ignore @permanent_link_pattern = permanent_link_pattern @scope = scope @bot_prompt = bot_prompt dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#bot_prompt ⇒ String?
33 34 35 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 33 def bot_prompt @bot_prompt end |
#description ⇒ String?
21 22 23 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 21 def description @description end |
#features ⇒ LiffFeatures?
24 25 26 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 24 def features @features end |
#permanent_link_pattern ⇒ String?
27 28 29 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 27 def permanent_link_pattern @permanent_link_pattern end |
#scope ⇒ Array['openid','email','profile','chat_message.write']
30 31 32 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 30 def scope @scope end |
#view ⇒ UpdateLiffView?
18 19 20 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 18 def view @view end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Liff::UpdateLiffAppRequest
Create an instance of the class from a hash
74 75 76 77 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 74 def self.create(args) # steep:ignore symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore end |
Instance Method Details
#==(other) ⇒ Boolean
81 82 83 84 85 86 87 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 81 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
90 91 92 |
# File 'lib/line/bot/v2/liff/model/update_liff_app_request.rb', line 90 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |