Class: Line::Bot::V2::MessagingApi::FlexOffset

Inherits:
Object
  • Object
show all
Defined in:
lib/line/bot/v2/messaging_api/model/flex_offset.rb

Overview

You can specify the offset of a component with the offset* property, in pixels or with a keyword. You can also specify the percentage to the box width for offsetStart and offsetEnd and to the box height for offsetTop and offsetBottom. FlexOffset just provides only keywords.