Class: Line::Bot::V2::Webhook::ActivatedEvent
- Defined in:
- lib/line/bot/v2/webhook/model/activated_event.rb
Overview
This event indicates that the module channel has been switched to Active Channel by calling the Acquire Control API. Sent to the webhook URL server of the module channel.
Instance Attribute Summary collapse
- #chat_control ⇒ ChatControl
- #delivery_context ⇒ DeliveryContext
-
#mode ⇒ String
(‘active’|‘standby’).
- #source ⇒ Source?
-
#timestamp ⇒ Integer
Time of the event in milliseconds.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
-
#webhook_event_id ⇒ String
Webhook Event ID.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Webhook::ActivatedEvent
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(source: nil, timestamp:, mode:, webhook_event_id:, delivery_context:, chat_control:, **dynamic_attributes) ⇒ ActivatedEvent
constructor
A new instance of ActivatedEvent.
Methods inherited from Event
Constructor Details
#initialize(source: nil, timestamp:, mode:, webhook_event_id:, delivery_context:, chat_control:, **dynamic_attributes) ⇒ ActivatedEvent
Returns a new instance of ActivatedEvent.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 47 def initialize( source: nil, timestamp:, mode:, webhook_event_id:, delivery_context:, chat_control:, **dynamic_attributes ) @type = "activated" @source = source.is_a?(Line::Bot::V2::Webhook::Source) || source.nil? ? source : Line::Bot::V2::Webhook::Source.create(**source) @timestamp = @mode = mode @webhook_event_id = webhook_event_id @delivery_context = delivery_context.is_a?(Line::Bot::V2::Webhook::DeliveryContext) ? delivery_context : Line::Bot::V2::Webhook::DeliveryContext.create(**delivery_context) @chat_control = chat_control.is_a?(Line::Bot::V2::Webhook::ChatControl) ? chat_control : Line::Bot::V2::Webhook::ChatControl.create(**chat_control) dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#chat_control ⇒ ChatControl
39 40 41 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 39 def chat_control @chat_control end |
#delivery_context ⇒ DeliveryContext
36 37 38 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 36 def delivery_context @delivery_context end |
#mode ⇒ String
Returns (‘active’|‘standby’).
30 31 32 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 30 def mode @mode end |
#source ⇒ Source?
24 25 26 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 24 def source @source end |
#timestamp ⇒ Integer
Returns Time of the event in milliseconds.
27 28 29 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 27 def @timestamp end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
21 22 23 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 21 def type @type end |
#webhook_event_id ⇒ String
Returns Webhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
33 34 35 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 33 def webhook_event_id @webhook_event_id end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Webhook::ActivatedEvent
Create an instance of the class from a hash
81 82 83 84 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 81 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
88 89 90 91 92 93 94 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 88 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
97 98 99 |
# File 'lib/line/bot/v2/webhook/model/activated_event.rb', line 97 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |