Class: Line::Bot::V2::Webhook::AudioMessageContent

Inherits:
MessageContent show all
Defined in:
lib/line/bot/v2/webhook/model/audio_message_content.rb

Overview

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MessageContent

detect_class

Constructor Details

#initialize(id:, content_provider:, duration: nil, mark_as_read_token: nil, **dynamic_attributes) ⇒ AudioMessageContent

Returns a new instance of AudioMessageContent.

Parameters:

  • id (String)

    Message ID

  • content_provider (ContentProvider, Hash[Symbol, untyped])
  • duration (Integer, nil) (defaults to: nil)

    Length of audio file (milliseconds)

  • mark_as_read_token (String, nil) (defaults to: nil)

    Token used to mark the message as read.



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/line/bot/v2/webhook/model/audio_message_content.rb', line 38

def initialize(
  id:,
  content_provider:,
  duration: nil,
  mark_as_read_token: nil,
  **dynamic_attributes
)
  @type = "audio"
  
  @id = id
  @content_provider = content_provider.is_a?(Line::Bot::V2::Webhook::ContentProvider) ? content_provider : Line::Bot::V2::Webhook::ContentProvider.create(**content_provider)
  @duration = duration
  @mark_as_read_token = mark_as_read_token

  dynamic_attributes.each do |key, value|
    self.class.attr_accessor key

    if value.is_a?(Hash)
      struct_klass = Struct.new(*value.keys.map(&:to_sym))
      struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v }
      instance_variable_set("@#{key}", struct_klass.new(*struct_values))
    else
      instance_variable_set("@#{key}", value)
    end
  end
end

Instance Attribute Details

#content_providerContentProvider

Returns:



26
27
28
# File 'lib/line/bot/v2/webhook/model/audio_message_content.rb', line 26

def content_provider
  @content_provider
end

#durationInteger?

Returns Length of audio file (milliseconds).

Returns:

  • (Integer, nil)

    Length of audio file (milliseconds)



29
30
31
# File 'lib/line/bot/v2/webhook/model/audio_message_content.rb', line 29

def duration
  @duration
end

#idString

Returns Message ID.

Returns:

  • (String)

    Message ID



23
24
25
# File 'lib/line/bot/v2/webhook/model/audio_message_content.rb', line 23

def id
  @id
end

#mark_as_read_tokenString?

Returns Token used to mark the message as read.

Returns:

  • (String, nil)

    Token used to mark the message as read.



32
33
34
# File 'lib/line/bot/v2/webhook/model/audio_message_content.rb', line 32

def mark_as_read_token
  @mark_as_read_token
end

#typeObject (readonly)

Returns the value of attribute type.



20
21
22
# File 'lib/line/bot/v2/webhook/model/audio_message_content.rb', line 20

def type
  @type
end

Class Method Details

.create(args) ⇒ Line::Bot::V2::Webhook::AudioMessageContent

Create an instance of the class from a hash

Parameters:

  • args (Hash)

    Hash containing all the required attributes

Returns:



68
69
70
71
# File 'lib/line/bot/v2/webhook/model/audio_message_content.rb', line 68

def self.create(args)
  symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args)
  return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments
end

Instance Method Details

#==(other) ⇒ Boolean

Returns true if the objects are equal, false otherwise.

Parameters:

  • other (Object)

    Object to compare

Returns:

  • (Boolean)

    true if the objects are equal, false otherwise



75
76
77
78
79
80
81
# File 'lib/line/bot/v2/webhook/model/audio_message_content.rb', line 75

def ==(other)
  return false unless self.class == other.class

  instance_variables.all? do |var|
      instance_variable_get(var) == other.instance_variable_get(var)
  end
end

#hashInteger

Returns Hash code of the object.

Returns:

  • (Integer)

    Hash code of the object



84
85
86
# File 'lib/line/bot/v2/webhook/model/audio_message_content.rb', line 84

def hash
  [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash
end