Class: Line::Bot::V2::Webhook::BotResumedEvent

Inherits:
Event
  • Object
show all
Defined in:
lib/line/bot/v2/webhook/model/bot_resumed_event.rb

Overview

This event indicates that the LINE Official Account has returned from the suspended state. Sent to the webhook URL server of the module channel.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Event

detect_class

Constructor Details

#initialize(source: nil, timestamp:, mode:, webhook_event_id:, delivery_context:, **dynamic_attributes) ⇒ BotResumedEvent

Returns a new instance of BotResumedEvent.

Parameters:

  • source (Source, Hash[Symbol, untyped], nil) (defaults to: nil)
  • timestamp (Integer)

    Time of the event in milliseconds.

  • mode (String)

    (‘active’|‘standby’)

  • webhook_event_id (String)

    Webhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.

  • delivery_context (DeliveryContext, Hash[Symbol, untyped])


43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 43

def initialize(
  source: nil,
  timestamp:,
  mode:,
  webhook_event_id:,
  delivery_context:,
  **dynamic_attributes
)
  @type = "botResumed"
  
  @source = source.is_a?(Line::Bot::V2::Webhook::Source) || source.nil? ? source : Line::Bot::V2::Webhook::Source.create(**source)
  @timestamp = timestamp
  @mode = mode
  @webhook_event_id = webhook_event_id
  @delivery_context = delivery_context.is_a?(Line::Bot::V2::Webhook::DeliveryContext) ? delivery_context : Line::Bot::V2::Webhook::DeliveryContext.create(**delivery_context)

  dynamic_attributes.each do |key, value|
    self.class.attr_accessor key

    if value.is_a?(Hash)
      struct_klass = Struct.new(*value.keys.map(&:to_sym))
      struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v }
      instance_variable_set("@#{key}", struct_klass.new(*struct_values))
    else
      instance_variable_set("@#{key}", value)
    end
  end
end

Instance Attribute Details

#delivery_contextDeliveryContext

Returns:



36
37
38
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 36

def delivery_context
  @delivery_context
end

#modeString

Returns (‘active’|‘standby’).

Returns:

  • (String)

    (‘active’|‘standby’)



30
31
32
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 30

def mode
  @mode
end

#sourceSource?

Returns:



24
25
26
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 24

def source
  @source
end

#timestampInteger

Returns Time of the event in milliseconds.

Returns:

  • (Integer)

    Time of the event in milliseconds.



27
28
29
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 27

def timestamp
  @timestamp
end

#typeObject (readonly)

Returns the value of attribute type.



21
22
23
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 21

def type
  @type
end

#webhook_event_idString

Returns Webhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.

Returns:

  • (String)

    Webhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.



33
34
35
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 33

def webhook_event_id
  @webhook_event_id
end

Class Method Details

.create(args) ⇒ Line::Bot::V2::Webhook::BotResumedEvent

Create an instance of the class from a hash

Parameters:

  • args (Hash)

    Hash containing all the required attributes

Returns:



75
76
77
78
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 75

def self.create(args)
  symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args)
  return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments
end

Instance Method Details

#==(other) ⇒ Boolean

Returns true if the objects are equal, false otherwise.

Parameters:

  • other (Object)

    Object to compare

Returns:

  • (Boolean)

    true if the objects are equal, false otherwise



82
83
84
85
86
87
88
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 82

def ==(other)
  return false unless self.class == other.class

  instance_variables.all? do |var|
      instance_variable_get(var) == other.instance_variable_get(var)
  end
end

#hashInteger

Returns Hash code of the object.

Returns:

  • (Integer)

    Hash code of the object



91
92
93
# File 'lib/line/bot/v2/webhook/model/bot_resumed_event.rb', line 91

def hash
  [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash
end