Class: Line::Bot::V2::Webhook::MembershipEvent
- Defined in:
- lib/line/bot/v2/webhook/model/membership_event.rb
Overview
This event indicates that a user has subscribed (joined), unsubscribed (left), or renewed the bot’s membership.
Instance Attribute Summary collapse
- #delivery_context ⇒ DeliveryContext
- #membership ⇒ MembershipContent
-
#mode ⇒ String
(‘active’|‘standby’).
-
#reply_token ⇒ String
Reply token used to send reply message to this event.
- #source ⇒ Source?
-
#timestamp ⇒ Integer
Time of the event in milliseconds.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
-
#webhook_event_id ⇒ String
Webhook Event ID.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Webhook::MembershipEvent
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(source: nil, timestamp:, mode:, webhook_event_id:, delivery_context:, reply_token:, membership:, **dynamic_attributes) ⇒ MembershipEvent
constructor
A new instance of MembershipEvent.
Methods inherited from Event
Constructor Details
#initialize(source: nil, timestamp:, mode:, webhook_event_id:, delivery_context:, reply_token:, membership:, **dynamic_attributes) ⇒ MembershipEvent
Returns a new instance of MembershipEvent.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 51 def initialize( source: nil, timestamp:, mode:, webhook_event_id:, delivery_context:, reply_token:, membership:, **dynamic_attributes ) @type = "membership" @source = source.is_a?(Line::Bot::V2::Webhook::Source) || source.nil? ? source : Line::Bot::V2::Webhook::Source.create(**source) @timestamp = @mode = mode @webhook_event_id = webhook_event_id @delivery_context = delivery_context.is_a?(Line::Bot::V2::Webhook::DeliveryContext) ? delivery_context : Line::Bot::V2::Webhook::DeliveryContext.create(**delivery_context) @reply_token = reply_token @membership = membership.is_a?(Line::Bot::V2::Webhook::MembershipContent) ? membership : Line::Bot::V2::Webhook::MembershipContent.create(**membership) dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#delivery_context ⇒ DeliveryContext
36 37 38 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 36 def delivery_context @delivery_context end |
#membership ⇒ MembershipContent
42 43 44 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 42 def membership @membership end |
#mode ⇒ String
Returns (‘active’|‘standby’).
30 31 32 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 30 def mode @mode end |
#reply_token ⇒ String
Returns Reply token used to send reply message to this event.
39 40 41 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 39 def reply_token @reply_token end |
#source ⇒ Source?
24 25 26 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 24 def source @source end |
#timestamp ⇒ Integer
Returns Time of the event in milliseconds.
27 28 29 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 27 def @timestamp end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
21 22 23 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 21 def type @type end |
#webhook_event_id ⇒ String
Returns Webhook Event ID. An ID that uniquely identifies a webhook event. This is a string in ULID format.
33 34 35 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 33 def webhook_event_id @webhook_event_id end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Webhook::MembershipEvent
Create an instance of the class from a hash
87 88 89 90 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 87 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
94 95 96 97 98 99 100 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 94 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
103 104 105 |
# File 'lib/line/bot/v2/webhook/model/membership_event.rb', line 103 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |