Class: Line::Bot::V2::Webhook::TextMessageContent

Inherits:
MessageContent show all
Defined in:
lib/line/bot/v2/webhook/model/text_message_content.rb

Overview

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MessageContent

detect_class

Constructor Details

#initialize(id:, text:, emojis: nil, mention: nil, quote_token:, quoted_message_id: nil, mark_as_read_token: nil, **dynamic_attributes) ⇒ TextMessageContent

Returns a new instance of TextMessageContent.

Parameters:

  • id (String)

    Message ID

  • text (String)

    Message text.

  • emojis (Array[Emoji, Hash[Symbol, untyped]], nil) (defaults to: nil)

    Array of one or more LINE emoji objects. Only included in the message event when the text property contains a LINE emoji.

  • mention (Mention, Hash[Symbol, untyped], nil) (defaults to: nil)
  • quote_token (String)

    Quote token to quote this message.

  • quoted_message_id (String, nil) (defaults to: nil)

    Message ID of a quoted message. Only included when the received message quotes a past message.

  • mark_as_read_token (String, nil) (defaults to: nil)

    Token used to mark the message as read.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 50

def initialize(
  id:,
  text:,
  emojis: nil,
  mention: nil,
  quote_token:,
  quoted_message_id: nil,
  mark_as_read_token: nil,
  **dynamic_attributes
)
  @type = "text"
  
  @id = id
  @text = text
  @emojis = emojis&.map do |item|
    if item.is_a?(Hash)
      Line::Bot::V2::Webhook::Emoji.create(**item)
    else
      item
    end
  end
  @mention = mention.is_a?(Line::Bot::V2::Webhook::Mention) || mention.nil? ? mention : Line::Bot::V2::Webhook::Mention.create(**mention)
  @quote_token = quote_token
  @quoted_message_id = quoted_message_id
  @mark_as_read_token = mark_as_read_token

  dynamic_attributes.each do |key, value|
    self.class.attr_accessor key

    if value.is_a?(Hash)
      struct_klass = Struct.new(*value.keys.map(&:to_sym))
      struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v }
      instance_variable_set("@#{key}", struct_klass.new(*struct_values))
    else
      instance_variable_set("@#{key}", value)
    end
  end
end

Instance Attribute Details

#emojisArray[Emoji]?

Returns Array of one or more LINE emoji objects. Only included in the message event when the text property contains a LINE emoji.

Returns:

  • (Array[Emoji], nil)

    Array of one or more LINE emoji objects. Only included in the message event when the text property contains a LINE emoji.



29
30
31
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 29

def emojis
  @emojis
end

#idString

Returns Message ID.

Returns:

  • (String)

    Message ID



23
24
25
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 23

def id
  @id
end

#mark_as_read_tokenString?

Returns Token used to mark the message as read.

Returns:

  • (String, nil)

    Token used to mark the message as read.



41
42
43
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 41

def mark_as_read_token
  @mark_as_read_token
end

#mentionMention?

Returns:



32
33
34
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 32

def mention
  @mention
end

#quote_tokenString

Returns Quote token to quote this message.

Returns:

  • (String)

    Quote token to quote this message.



35
36
37
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 35

def quote_token
  @quote_token
end

#quoted_message_idString?

Returns Message ID of a quoted message. Only included when the received message quotes a past message.

Returns:

  • (String, nil)

    Message ID of a quoted message. Only included when the received message quotes a past message.



38
39
40
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 38

def quoted_message_id
  @quoted_message_id
end

#textString

Returns Message text.

Returns:

  • (String)

    Message text.



26
27
28
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 26

def text
  @text
end

#typeObject (readonly)

Returns the value of attribute type.



20
21
22
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 20

def type
  @type
end

Class Method Details

.create(args) ⇒ Line::Bot::V2::Webhook::TextMessageContent

Create an instance of the class from a hash

Parameters:

  • args (Hash)

    Hash containing all the required attributes

Returns:



92
93
94
95
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 92

def self.create(args)
  symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args)
  return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments
end

Instance Method Details

#==(other) ⇒ Boolean

Returns true if the objects are equal, false otherwise.

Parameters:

  • other (Object)

    Object to compare

Returns:

  • (Boolean)

    true if the objects are equal, false otherwise



99
100
101
102
103
104
105
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 99

def ==(other)
  return false unless self.class == other.class

  instance_variables.all? do |var|
      instance_variable_get(var) == other.instance_variable_get(var)
  end
end

#hashInteger

Returns Hash code of the object.

Returns:

  • (Integer)

    Hash code of the object



108
109
110
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 108

def hash
  [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash
end