Class: Line::Bot::V2::Webhook::VideoMessageContent
- Inherits:
-
MessageContent
- Object
- MessageContent
- Line::Bot::V2::Webhook::VideoMessageContent
- Defined in:
- lib/line/bot/v2/webhook/model/video_message_content.rb
Overview
Instance Attribute Summary collapse
- #content_provider ⇒ ContentProvider
-
#duration ⇒ Integer?
Length of video file (milliseconds).
-
#id ⇒ String
Message ID.
-
#mark_as_read_token ⇒ String?
Token used to mark the message as read.
-
#quote_token ⇒ String
Quote token to quote this message.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Webhook::VideoMessageContent
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(id:, duration: nil, content_provider:, quote_token:, mark_as_read_token: nil, **dynamic_attributes) ⇒ VideoMessageContent
constructor
A new instance of VideoMessageContent.
Methods inherited from MessageContent
Constructor Details
#initialize(id:, duration: nil, content_provider:, quote_token:, mark_as_read_token: nil, **dynamic_attributes) ⇒ VideoMessageContent
Returns a new instance of VideoMessageContent.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 42 def initialize( id:, duration: nil, content_provider:, quote_token:, mark_as_read_token: nil, **dynamic_attributes ) @type = "video" @id = id @duration = duration @content_provider = content_provider.is_a?(Line::Bot::V2::Webhook::ContentProvider) ? content_provider : Line::Bot::V2::Webhook::ContentProvider.create(**content_provider) @quote_token = quote_token @mark_as_read_token = mark_as_read_token dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#content_provider ⇒ ContentProvider
29 30 31 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 29 def content_provider @content_provider end |
#duration ⇒ Integer?
Returns Length of video file (milliseconds).
26 27 28 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 26 def duration @duration end |
#id ⇒ String
Returns Message ID.
23 24 25 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 23 def id @id end |
#mark_as_read_token ⇒ String?
Returns Token used to mark the message as read.
35 36 37 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 35 def mark_as_read_token @mark_as_read_token end |
#quote_token ⇒ String
Returns Quote token to quote this message.
32 33 34 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 32 def quote_token @quote_token end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
20 21 22 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 20 def type @type end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Webhook::VideoMessageContent
Create an instance of the class from a hash
74 75 76 77 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 74 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
81 82 83 84 85 86 87 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 81 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
90 91 92 |
# File 'lib/line/bot/v2/webhook/model/video_message_content.rb', line 90 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |