Class: Line::Bot::V2::Webhook::VideoPlayComplete

Inherits:
Object
  • Object
show all
Defined in:
lib/line/bot/v2/webhook/model/video_play_complete.rb

Overview

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(tracking_id:, **dynamic_attributes) ⇒ VideoPlayComplete

Returns a new instance of VideoPlayComplete.

Parameters:

  • tracking_id (String)

    ID used to identify a video. Returns the same value as the trackingId assigned to the video message.



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/line/bot/v2/webhook/model/video_play_complete.rb', line 21

def initialize(
  tracking_id:,
  **dynamic_attributes
)
  
  @tracking_id = tracking_id

  dynamic_attributes.each do |key, value|
    self.class.attr_accessor key

    if value.is_a?(Hash)
      struct_klass = Struct.new(*value.keys.map(&:to_sym))
      struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v }
      instance_variable_set("@#{key}", struct_klass.new(*struct_values))
    else
      instance_variable_set("@#{key}", value)
    end
  end
end

Instance Attribute Details

#tracking_idString

Returns ID used to identify a video. Returns the same value as the trackingId assigned to the video message.

Returns:

  • (String)

    ID used to identify a video. Returns the same value as the trackingId assigned to the video message.



18
19
20
# File 'lib/line/bot/v2/webhook/model/video_play_complete.rb', line 18

def tracking_id
  @tracking_id
end

Class Method Details

.create(args) ⇒ Line::Bot::V2::Webhook::VideoPlayComplete

Create an instance of the class from a hash

Parameters:

  • args (Hash)

    Hash containing all the required attributes

Returns:



44
45
46
47
# File 'lib/line/bot/v2/webhook/model/video_play_complete.rb', line 44

def self.create(args)
  symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args)
  return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments
end

Instance Method Details

#==(other) ⇒ Boolean

Returns true if the objects are equal, false otherwise.

Parameters:

  • other (Object)

    Object to compare

Returns:

  • (Boolean)

    true if the objects are equal, false otherwise



51
52
53
54
55
56
57
# File 'lib/line/bot/v2/webhook/model/video_play_complete.rb', line 51

def ==(other)
  return false unless self.class == other.class

  instance_variables.all? do |var|
      instance_variable_get(var) == other.instance_variable_get(var)
  end
end

#hashInteger

Returns Hash code of the object.

Returns:

  • (Integer)

    Hash code of the object



60
61
62
# File 'lib/line/bot/v2/webhook/model/video_play_complete.rb', line 60

def hash
  [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash
end