Class: Line::Bot::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/line/bot/client.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) {|_self| ... } ⇒ Line::Bot::Client

Initialize a new Bot Client.

Parameters:

  • options (Hash) (defaults to: {})

Yields:

  • (_self)

Yield Parameters:



35
36
37
38
39
40
# File 'lib/line/bot/client.rb', line 35

def initialize(options = {})
  options.each do |key, value|
    instance_variable_set("@#{key}", value)
  end
  yield(self) if block_given?
end

Instance Attribute Details

#channel_secretObject

@return [String]



25
26
27
# File 'lib/line/bot/client.rb', line 25

def channel_secret
  @channel_secret
end

#channel_tokenObject

@return [String]



25
26
27
# File 'lib/line/bot/client.rb', line 25

def channel_token
  @channel_token
end

#endpointObject

@return [String]



25
26
27
# File 'lib/line/bot/client.rb', line 25

def endpoint
  @endpoint
end

#httpclientObject

Returns:

  • (Object)


28
29
30
# File 'lib/line/bot/client.rb', line 28

def httpclient
  @httpclient
end

Instance Method Details

#create_rich_menu(rich_menu) ⇒ Net::HTTPResponse

Create a rich menu

Parameters:

  • rich_menu (Hash)

    The rich menu represented as a rich menu object

Returns:

  • (Net::HTTPResponse)


248
249
250
251
252
253
254
255
256
257
258
# File 'lib/line/bot/client.rb', line 248

def create_rich_menu(rich_menu)
  request = Request.new do |config|
    config.httpclient     = httpclient
    config.endpoint       = endpoint
    config.endpoint_path  = '/bot/richmenu'
    config.credentials    = credentials
    config.payload        = rich_menu.to_json
  end

  request.post
end

#create_rich_menu_image(rich_menu_id, file) ⇒ Net::HTTPResponse

Upload and attaches an image to a rich menu

Parameters:

  • rich_menu_id (String)

    The ID of the rich menu to attach the image to

  • file (File)

    Image file to attach rich menu

Returns:

  • (Net::HTTPResponse)


323
324
325
326
327
328
329
330
331
332
333
# File 'lib/line/bot/client.rb', line 323

def create_rich_menu_image(rich_menu_id, file)
  request = Request.new do |config|
    config.httpclient     = httpclient
    config.endpoint       = endpoint
    config.endpoint_path  = "/bot/richmenu/#{rich_menu_id}/content"
    config.credentials = credentials
    config.file = file
  end

  request.post
end

#credentialsHash

Returns:

  • (Hash)


51
52
53
54
55
# File 'lib/line/bot/client.rb', line 51

def credentials
  {
    "Authorization" => "Bearer #{channel_token}",
  }
end

#credentials?Boolean

Returns:

  • (Boolean)


57
58
59
# File 'lib/line/bot/client.rb', line 57

def credentials?
  credentials.values.all?
end

#delete(endpoint_path) ⇒ Net::HTTPResponse

Delete content of specified URL.

Parameters:

  • endpoint_path (String)

Returns:

  • (Net::HTTPResponse)

Raises:



358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/line/bot/client.rb', line 358

def delete(endpoint_path)
  raise Line::Bot::API::InvalidCredentialsError, 'Invalidates credentials' unless credentials?

  request = Request.new do |config|
    config.httpclient     = httpclient
    config.endpoint       = endpoint
    config.endpoint_path  = endpoint_path
    config.credentials    = credentials
  end

  request.delete
end

#delete_rich_menu(rich_menu_id) ⇒ Net::HTTPResponse

Delete a rich menu

Parameters:

  • rich_menu_id (String)

    ID of an uploaded rich menu

Returns:

  • (Net::HTTPResponse)


265
266
267
268
# File 'lib/line/bot/client.rb', line 265

def delete_rich_menu(rich_menu_id)
  endpoint_path = "/bot/richmenu/#{rich_menu_id}"
  delete(endpoint_path)
end

#get(endpoint_path) ⇒ Net::HTTPResponse

Fetch data, get content of specified URL.

Parameters:

  • endpoint_path (String)

Returns:

  • (Net::HTTPResponse)

Raises:



340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/line/bot/client.rb', line 340

def get(endpoint_path)
  raise Line::Bot::API::InvalidCredentialsError, 'Invalidates credentials' unless credentials?

  request = Request.new do |config|
    config.httpclient     = httpclient
    config.endpoint       = endpoint
    config.endpoint_path  = endpoint_path
    config.credentials    = credentials
  end

  request.get
end

#get_group_member_ids(group_id, continuation_token = nil) ⇒ Net::HTTPResponse

Get user IDs of a group

Parameters:

  • group_id (String)

    Group’s identifier

  • continuation_token (String) (defaults to: nil)

    Identifier to return next page (next property to be included in the response)

Returns:

  • (Net::HTTPResponse)


206
207
208
209
210
# File 'lib/line/bot/client.rb', line 206

def get_group_member_ids(group_id, continuation_token = nil)
  endpoint_path  = "/bot/group/#{group_id}/members/ids"
  endpoint_path += "?start=#{continuation_token}" if continuation_token
  get(endpoint_path)
end

#get_group_member_profile(group_id, user_id) ⇒ Net::HTTPResponse

Get an user’s profile of a group.

Parameters:

  • group_id (String)

    Group’s identifier

  • user_id (String)

    User’s identifier

Returns:

  • (Net::HTTPResponse)


183
184
185
186
# File 'lib/line/bot/client.rb', line 183

def get_group_member_profile(group_id, user_id)
  endpoint_path = "/bot/group/#{group_id}/member/#{user_id}"
  get(endpoint_path)
end

#get_message_content(identifier) ⇒ Net::HTTPResponse

Get message content.

Parameters:

  • identifier (String)

    Message’s identifier

Returns:

  • (Net::HTTPResponse)


162
163
164
165
# File 'lib/line/bot/client.rb', line 162

def get_message_content(identifier)
  endpoint_path  = "/bot/message/#{identifier}/content"
  get(endpoint_path)
end

#get_profile(user_id) ⇒ Net::HTTPResponse

Get an user’s profile.

Parameters:

  • user_id (String)

    User’s identifier

Returns:

  • (Net::HTTPResponse)


172
173
174
175
# File 'lib/line/bot/client.rb', line 172

def get_profile(user_id)
  endpoint_path  = "/bot/profile/#{user_id}"
  get(endpoint_path)
end

#get_rich_menu(rich_menu_id) ⇒ Net::HTTPResponse

Get a rich menu via a rich menu ID

Parameters:

  • rich_menu_id (String)

    ID of an uploaded rich menu

Returns:

  • (Net::HTTPResponse)


238
239
240
241
# File 'lib/line/bot/client.rb', line 238

def get_rich_menu(rich_menu_id)
  endpoint_path = "/bot/richmenu/#{rich_menu_id}"
  get(endpoint_path)
end

#get_rich_menu_image(rich_menu_id) ⇒ Net::HTTPResponse

Download an image associated with a rich menu

Parameters:

  • rich_menu_id (String)

    ID of an uploaded rich menu

Returns:

  • (Net::HTTPResponse)


312
313
314
315
# File 'lib/line/bot/client.rb', line 312

def get_rich_menu_image(rich_menu_id)
  endpoint_path = "/bot/richmenu/#{rich_menu_id}/content"
  get(endpoint_path)
end

#get_rich_menusNet::HTTPResponse

Get a list of all uploaded rich menus

Returns:

  • (Net::HTTPResponse)


228
229
230
231
# File 'lib/line/bot/client.rb', line 228

def get_rich_menus
  endpoint_path = '/bot/richmenu/list'
  get(endpoint_path)
end

#get_room_member_ids(room_id, continuation_token = nil) ⇒ Net::HTTPResponse

Get user IDs of a room

Parameters:

  • group_id (String)

    Room’s identifier

  • continuation_token (String) (defaults to: nil)

    Identifier to return next page (next property to be included in the response)

Returns:

  • (Net::HTTPResponse)


219
220
221
222
223
# File 'lib/line/bot/client.rb', line 219

def get_room_member_ids(room_id, continuation_token = nil)
  endpoint_path  = "/bot/room/#{room_id}/members/ids"
  endpoint_path += "?start=#{continuation_token}" if continuation_token
  get(endpoint_path)
end

#get_room_member_profile(room_id, user_id) ⇒ Net::HTTPResponse

Get an user’s profile of a room.

Parameters:

  • room_id (String)

    Room’s identifier

  • user_id (String)

    User’s identifier

Returns:

  • (Net::HTTPResponse)


194
195
196
197
# File 'lib/line/bot/client.rb', line 194

def get_room_member_profile(room_id, user_id)
  endpoint_path = "/bot/room/#{room_id}/member/#{user_id}"
  get(endpoint_path)
end

#get_user_rich_menu(user_id) ⇒ Net::HTTPResponse

Get the ID of the rich menu linked to a user

Parameters:

  • user_id (String)

    ID of the user

Returns:

  • (Net::HTTPResponse)


275
276
277
278
# File 'lib/line/bot/client.rb', line 275

def get_user_rich_menu(user_id)
  endpoint_path = "/bot/user/#{user_id}/richmenu"
  get(endpoint_path)
end

#leave_group(group_id) ⇒ Object



131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/line/bot/client.rb', line 131

def leave_group(group_id)
  raise Line::Bot::API::InvalidCredentialsError, 'Invalidates credentials' unless credentials?

  request = Request.new do |config|
    config.httpclient     = httpclient
    config.endpoint       = endpoint
    config.endpoint_path  = "/bot/group/#{group_id}/leave"
    config.credentials    = credentials
  end

  request.post
end

#leave_room(room_id) ⇒ Object



144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/line/bot/client.rb', line 144

def leave_room(room_id)
  raise Line::Bot::API::InvalidCredentialsError, 'Invalidates credentials' unless credentials?

  request = Request.new do |config|
    config.httpclient     = httpclient
    config.endpoint       = endpoint
    config.endpoint_path  = "/bot/room/#{room_id}/leave"
    config.credentials    = credentials
  end

  request.post
end

Link a rich menu to a user

Parameters:

  • user_id (String)

    ID of the user

  • rich_menu_id (String)

    ID of an uploaded rich menu

Returns:

  • (Net::HTTPResponse)


286
287
288
289
290
291
292
293
294
295
# File 'lib/line/bot/client.rb', line 286

def link_user_rich_menu(user_id, rich_menu_id)
  request = Request.new do |config|
    config.httpclient = httpclient
    config.endpoint = endpoint
    config.endpoint_path = "/bot/user/#{user_id}/richmenu/#{rich_menu_id}"
    config.credentials = credentials
  end

  request.post
end

#multicast(to, messages) ⇒ Net::HTTPResponse

Multicast messages to line server and to users.

Parameters:

  • to (Array or String)
  • messages (Hash or Array)

Returns:

  • (Net::HTTPResponse)

Raises:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/line/bot/client.rb', line 113

def multicast(to, messages)
  raise Line::Bot::API::InvalidCredentialsError, 'Invalidates credentials' unless credentials?

  to = [to] if to.is_a?(String)
  messages = [messages] if messages.is_a?(Hash)

  request = Request.new do |config|
    config.httpclient     = httpclient
    config.endpoint       = endpoint
    config.endpoint_path  = '/bot/message/multicast'
    config.credentials    = credentials
    config.to             = to
    config.messages       = messages
  end

  request.post
end

#parse_events_from(request_body) ⇒ Array<Line::Bot::Event::Class>

Parse events from request.body

Parameters:

  • request_body (String)

Returns:

  • (Array<Line::Bot::Event::Class>)


376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/line/bot/client.rb', line 376

def parse_events_from(request_body)
  json = JSON.parse(request_body)

  json['events'].map { |item|
    begin
      klass = Line::Bot::Event.const_get(item['type'].capitalize)
      klass.new(item)
    rescue NameError => e
      Line::Bot::Event::Base.new(item)
    end
  }
end

#push_message(user_id, messages) ⇒ Net::HTTPResponse

Push messages to line server and to user.

Parameters:

  • user_id (String)

    User’s identifiers

  • messages (Hash or Array)

Returns:

  • (Net::HTTPResponse)

Raises:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/line/bot/client.rb', line 67

def push_message(user_id, messages)
  raise Line::Bot::API::InvalidCredentialsError, 'Invalidates credentials' unless credentials?

  messages = [messages] if messages.is_a?(Hash)

  request = Request.new do |config|
    config.httpclient     = httpclient
    config.endpoint       = endpoint
    config.endpoint_path  = '/bot/message/push'
    config.credentials    = credentials
    config.to             = user_id
    config.messages       = messages
  end

  request.post
end

#reply_message(token, messages) ⇒ Net::HTTPResponse

Reply messages to line server and to users.

Parameters:

  • token (String)
  • messages (Hash or Array)

Returns:

  • (Net::HTTPResponse)

Raises:



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/line/bot/client.rb', line 90

def reply_message(token, messages)
  raise Line::Bot::API::InvalidCredentialsError, 'Invalidates credentials' unless credentials?

  messages = [messages] if messages.is_a?(Hash)

  request = Request.new do |config|
    config.httpclient     = httpclient
    config.endpoint       = endpoint
    config.endpoint_path  = '/bot/message/reply'
    config.credentials    = credentials
    config.reply_token    = token
    config.messages       = messages
  end

  request.post
end

Unlink a rich menu from a user

Parameters:

  • user_id (String)

    ID of the user

Returns:

  • (Net::HTTPResponse)


302
303
304
305
# File 'lib/line/bot/client.rb', line 302

def unlink_user_rich_menu(user_id)
  endpoint_path  = "/bot/user/#{user_id}/richmenu"
  delete(endpoint_path)
end

#validate_signature(content, channel_signature) ⇒ Boolean

Validate signature

Parameters:

  • content (String)

    Request’s body

  • channel_signature (String)

    Request’header ‘X-LINE-Signature’ # HTTP_X_LINE_SIGNATURE

Returns:

  • (Boolean)


395
396
397
398
399
400
401
402
# File 'lib/line/bot/client.rb', line 395

def validate_signature(content, channel_signature)
  return false if !channel_signature || !channel_secret

  hash = OpenSSL::HMAC.digest(OpenSSL::Digest::SHA256.new, channel_secret, content)
  signature = Base64.strict_encode64(hash)

  variable_secure_compare(channel_signature, signature)
end