Class: Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseClick
- Inherits:
-
Object
- Object
- Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseClick
- Defined in:
- lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_click.rb,
sig/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_click.rbs
Overview
Click metrics for a single tappable area of the rich menu.
Instance Attribute Summary collapse
- #bounds ⇒ GetRichMenuInsightSummaryResponseBounds
- #metrics ⇒ GetRichMenuInsightSummaryResponseMetrics
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseClick
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
- #initialize(bounds:, metrics:, **dynamic_attributes) ⇒ Object constructor
Constructor Details
#initialize(bounds:, metrics:, **dynamic_attributes) ⇒ Object
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_click.rb', line 25 def initialize( bounds:, metrics:, **dynamic_attributes ) @bounds = bounds.is_a?(Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseBounds) ? bounds : Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseBounds.create(**bounds) @metrics = metrics.is_a?(Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseMetrics) ? metrics : Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseMetrics.create(**metrics) dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#bounds ⇒ GetRichMenuInsightSummaryResponseBounds
18 19 20 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_click.rb', line 18 def bounds @bounds end |
#metrics ⇒ GetRichMenuInsightSummaryResponseMetrics
21 22 23 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_click.rb', line 21 def metrics @metrics end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Insight::GetRichMenuInsightSummaryResponseClick
Create an instance of the class from a hash
50 51 52 53 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_click.rb', line 50 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
57 58 59 60 61 62 63 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_click.rb', line 57 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
66 67 68 |
# File 'lib/line/bot/v2/insight/model/get_rich_menu_insight_summary_response_click.rb', line 66 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |