Class: Line::Bot::V2::MessagingApi::GetFollowersResponse
- Inherits:
-
Object
- Object
- Line::Bot::V2::MessagingApi::GetFollowersResponse
- Defined in:
- lib/line/bot/v2/messaging_api/model/get_followers_response.rb
Overview
Instance Attribute Summary collapse
-
#_next ⇒ String?
A continuation token to get the next array of user IDs.
-
#user_ids ⇒ Array[String]
An array of strings indicating user IDs of users that have added the LINE Official Account as a friend.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::MessagingApi::GetFollowersResponse
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(user_ids:, _next: nil, **dynamic_attributes) ⇒ GetFollowersResponse
constructor
A new instance of GetFollowersResponse.
Constructor Details
#initialize(user_ids:, _next: nil, **dynamic_attributes) ⇒ GetFollowersResponse
Returns a new instance of GetFollowersResponse.
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/line/bot/v2/messaging_api/model/get_followers_response.rb', line 25 def initialize( user_ids:, _next: nil, **dynamic_attributes ) @user_ids = user_ids @_next = _next dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#_next ⇒ String?
Returns A continuation token to get the next array of user IDs. Returned only when there are remaining user IDs that weren’t returned in userIds in the original request. The number of user IDs in the userIds element doesn’t have to reach the maximum number specified by limit for the next property to be included in the response.
21 22 23 |
# File 'lib/line/bot/v2/messaging_api/model/get_followers_response.rb', line 21 def _next @_next end |
#user_ids ⇒ Array[String]
Returns An array of strings indicating user IDs of users that have added the LINE Official Account as a friend. Only users of LINE for iOS and LINE for Android are included in userIds.
18 19 20 |
# File 'lib/line/bot/v2/messaging_api/model/get_followers_response.rb', line 18 def user_ids @user_ids end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::MessagingApi::GetFollowersResponse
Create an instance of the class from a hash
50 51 52 53 |
# File 'lib/line/bot/v2/messaging_api/model/get_followers_response.rb', line 50 def self.create(args) # steep:ignore symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
57 58 59 60 61 62 63 |
# File 'lib/line/bot/v2/messaging_api/model/get_followers_response.rb', line 57 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
66 67 68 |
# File 'lib/line/bot/v2/messaging_api/model/get_followers_response.rb', line 66 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |