Class: Line::Bot::V2::Webhook::LocationMessageContent
- Inherits:
-
MessageContent
- Object
- MessageContent
- Line::Bot::V2::Webhook::LocationMessageContent
- Defined in:
- lib/line/bot/v2/webhook/model/location_message_content.rb
Overview
Instance Attribute Summary collapse
-
#address ⇒ String?
Address.
-
#id ⇒ String
Message ID.
-
#latitude ⇒ Float
Latitude.
-
#longitude ⇒ Float
Longitude.
-
#mark_as_read_token ⇒ String?
Token used to mark the message as read.
-
#title ⇒ String?
Title.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Webhook::LocationMessageContent
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(id:, title: nil, address: nil, latitude:, longitude:, mark_as_read_token: nil, **dynamic_attributes) ⇒ LocationMessageContent
constructor
A new instance of LocationMessageContent.
Methods inherited from MessageContent
Constructor Details
#initialize(id:, title: nil, address: nil, latitude:, longitude:, mark_as_read_token: nil, **dynamic_attributes) ⇒ LocationMessageContent
Returns a new instance of LocationMessageContent.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 46 def initialize( id:, title: nil, address: nil, latitude:, longitude:, mark_as_read_token: nil, **dynamic_attributes ) @type = "location" @id = id @title = title @address = address @latitude = latitude @longitude = longitude @mark_as_read_token = mark_as_read_token dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#address ⇒ String?
Returns Address.
29 30 31 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 29 def address @address end |
#id ⇒ String
Returns Message ID.
23 24 25 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 23 def id @id end |
#latitude ⇒ Float
Returns Latitude.
32 33 34 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 32 def latitude @latitude end |
#longitude ⇒ Float
Returns Longitude.
35 36 37 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 35 def longitude @longitude end |
#mark_as_read_token ⇒ String?
Returns Token used to mark the message as read.
38 39 40 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 38 def mark_as_read_token @mark_as_read_token end |
#title ⇒ String?
Returns Title.
26 27 28 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 26 def title @title end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
20 21 22 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 20 def type @type end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Webhook::LocationMessageContent
Create an instance of the class from a hash
80 81 82 83 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 80 def self.create(args) symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore InsufficientKeywordArguments end |
Instance Method Details
#==(other) ⇒ Boolean
Returns true if the objects are equal, false otherwise.
87 88 89 90 91 92 93 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 87 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
Returns Hash code of the object.
96 97 98 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 96 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |