Class: Line::Bot::V2::Webhook::LocationMessageContent
- Inherits:
-
MessageContent
- Object
- MessageContent
- Line::Bot::V2::Webhook::LocationMessageContent
- Defined in:
- lib/line/bot/v2/webhook/model/location_message_content.rb
Instance Attribute Summary collapse
-
#address ⇒ String?
Address.
-
#id ⇒ String
Message ID.
-
#latitude ⇒ Float
Latitude.
-
#longitude ⇒ Float
Longitude.
-
#title ⇒ String?
Title.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Webhook::LocationMessageContent
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(id:, title: nil, address: nil, latitude:, longitude:, **dynamic_attributes) ⇒ LocationMessageContent
constructor
A new instance of LocationMessageContent.
Constructor Details
#initialize(id:, title: nil, address: nil, latitude:, longitude:, **dynamic_attributes) ⇒ LocationMessageContent
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 41 def initialize( id:, title: nil, address: nil, latitude:, longitude:, **dynamic_attributes ) @type = "location" @id = id @title = title @address = address @latitude = latitude @longitude = longitude dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#address ⇒ String?
28 29 30 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 28 def address @address end |
#id ⇒ String
22 23 24 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 22 def id @id end |
#latitude ⇒ Float
31 32 33 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 31 def latitude @latitude end |
#longitude ⇒ Float
34 35 36 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 34 def longitude @longitude end |
#title ⇒ String?
25 26 27 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 25 def title @title end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
19 20 21 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 19 def type @type end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Webhook::LocationMessageContent
Create an instance of the class from a hash
73 74 75 76 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 73 def self.create(args) # steep:ignore symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore end |
Instance Method Details
#==(other) ⇒ Boolean
80 81 82 83 84 85 86 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 80 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
89 90 91 |
# File 'lib/line/bot/v2/webhook/model/location_message_content.rb', line 89 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |