Class: Line::Bot::V2::Webhook::TextMessageContent
- Inherits:
-
MessageContent
- Object
- MessageContent
- Line::Bot::V2::Webhook::TextMessageContent
- Defined in:
- lib/line/bot/v2/webhook/model/text_message_content.rb
Instance Attribute Summary collapse
-
#emojis ⇒ Array[Emoji]?
Array of one or more LINE emoji objects.
-
#id ⇒ String
Message ID.
- #mention ⇒ Mention?
-
#quote_token ⇒ String
Quote token to quote this message.
-
#quoted_message_id ⇒ String?
Message ID of a quoted message.
-
#text ⇒ String
Message text.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
Class Method Summary collapse
-
.create(args) ⇒ Line::Bot::V2::Webhook::TextMessageContent
Create an instance of the class from a hash.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
True if the objects are equal, false otherwise.
-
#hash ⇒ Integer
Hash code of the object.
-
#initialize(id:, text:, emojis: nil, mention: nil, quote_token:, quoted_message_id: nil, **dynamic_attributes) ⇒ TextMessageContent
constructor
A new instance of TextMessageContent.
Constructor Details
#initialize(id:, text:, emojis: nil, mention: nil, quote_token:, quoted_message_id: nil, **dynamic_attributes) ⇒ TextMessageContent
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 45 def initialize( id:, text:, emojis: nil, mention: nil, quote_token:, quoted_message_id: nil, **dynamic_attributes ) @type = "text" @id = id @text = text @emojis = emojis&.map do |item| if item.is_a?(Hash) Line::Bot::V2::Webhook::Emoji.create(**item) # steep:ignore InsufficientKeywordArguments else item end end @mention = mention.is_a?(Line::Bot::V2::Webhook::Mention) || mention.nil? ? mention : Line::Bot::V2::Webhook::Mention.create(**mention) # steep:ignore @quote_token = quote_token = dynamic_attributes.each do |key, value| self.class.attr_accessor key if value.is_a?(Hash) struct_klass = Struct.new(*value.keys.map(&:to_sym)) struct_values = value.map { |_k, v| v.is_a?(Hash) ? Line::Bot::V2::Utils.hash_to_struct(v) : v } instance_variable_set("@#{key}", struct_klass.new(*struct_values)) else instance_variable_set("@#{key}", value) end end end |
Instance Attribute Details
#emojis ⇒ Array[Emoji]?
28 29 30 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 28 def emojis @emojis end |
#id ⇒ String
22 23 24 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 22 def id @id end |
#mention ⇒ Mention?
31 32 33 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 31 def mention @mention end |
#quote_token ⇒ String
34 35 36 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 34 def quote_token @quote_token end |
#quoted_message_id ⇒ String?
37 38 39 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 37 def end |
#text ⇒ String
25 26 27 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 25 def text @text end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
19 20 21 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 19 def type @type end |
Class Method Details
.create(args) ⇒ Line::Bot::V2::Webhook::TextMessageContent
Create an instance of the class from a hash
85 86 87 88 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 85 def self.create(args) # steep:ignore symbolized_args = Line::Bot::V2::Utils.deep_symbolize(args) return new(**symbolized_args) # steep:ignore end |
Instance Method Details
#==(other) ⇒ Boolean
92 93 94 95 96 97 98 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 92 def ==(other) return false unless self.class == other.class instance_variables.all? do |var| instance_variable_get(var) == other.instance_variable_get(var) end end |
#hash ⇒ Integer
101 102 103 |
# File 'lib/line/bot/v2/webhook/model/text_message_content.rb', line 101 def hash [self.class, *instance_variables.map { |var| instance_variable_get(var) }].hash end |